aboutsummaryrefslogtreecommitdiff
path: root/src/armnn/test/ProfilingEventTest.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/armnn/test/ProfilingEventTest.cpp')
-rw-r--r--src/armnn/test/ProfilingEventTest.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/armnn/test/ProfilingEventTest.cpp b/src/armnn/test/ProfilingEventTest.cpp
index 33396b1a19..9e31ccb323 100644
--- a/src/armnn/test/ProfilingEventTest.cpp
+++ b/src/armnn/test/ProfilingEventTest.cpp
@@ -32,8 +32,8 @@ BOOST_AUTO_TEST_CASE(ProfilingEventTest)
// start the timer - outer
testEvent.Start();
- // wait for 10 milliseconds
- std::this_thread::sleep_for(std::chrono::milliseconds(10));
+ // wait for 10 microseconds
+ std::this_thread::sleep_for(std::chrono::microseconds(10));
// stop the timer - outer
testEvent.Stop();
@@ -74,8 +74,8 @@ BOOST_AUTO_TEST_CASE(ProfilingEventTestOnGpuAcc)
// start the timer - outer
testEvent.Start();
- // wait for 10 milliseconds
- std::this_thread::sleep_for(std::chrono::milliseconds(10));
+ // wait for 10 microseconds
+ std::this_thread::sleep_for(std::chrono::microseconds(10));
// stop the timer - outer
testEvent.Stop();